@@ -12,6 +12,7 @@ from starlite.config import (
     CacheConfig,
     CompressionConfig,
     CORSConfig,
+    CSRFConfig,
     OpenAPIConfig,
     StaticFilesConfig,
     TemplateConfig,
@@ -20,7 +21,7 @@ from starlite.datastructures import Cookie, ResponseHeader, State
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.asgi import ASGIRouteHandler, asgi
 from starlite.handlers.http import HTTPRouteHandler
-from starlite.middleware import ExceptionHandlerMiddleware
+from starlite.middleware import CSRFMiddleware, ExceptionHandlerMiddleware
 from starlite.middleware.compression.base import CompressionMiddleware
 from starlite.plugins.base import PluginProtocol
 from starlite.provide import Provide
@@ -61,6 +62,7 @@ class Starlite(Router):
         "asgi_router",
         "cache_config",
         "cors_config",
+        "csrf_config",
         "debug",
         "compression_config",
         "openapi_schema",
@@ -83,6 +85,7 @@ class Starlite(Router):
         cache_config: CacheConfig = DEFAULT_CACHE_CONFIG,
         compression_config: Optional[CompressionConfig] = None,
         cors_config: Optional[CORSConfig] = None,
+        csrf_config: Optional[CSRFConfig] = None,
         debug: bool = False,
         dependencies: Optional[Dict[str, Provide]] = None,
         exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
@@ -122,6 +125,7 @@ class Starlite(Router):
             cache_config: Configures caching behavior of the application.
             compression_config: Configures compression behaviour of the application.
             cors_config: If set this enables the `starlette.middleware.cores.CORSMiddleware`.
+            csrf_config: If set this enables the CSRF middleware.
             debug: If `True`, app errors rendered as HTML with a stack trace.
             dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
@@ -148,6 +152,7 @@ class Starlite(Router):
         self.allowed_hosts = allowed_hosts
         self.cache_config = cache_config
         self.cors_config = cors_config
+        self.csrf_config = csrf_config
         self.debug = debug
         self.compression_config = compression_config
         self.plain_routes: Set[str] = set()
@@ -202,6 +207,8 @@ class Starlite(Router):
             asgi_handler = TrustedHostMiddleware(app=asgi_handler, allowed_hosts=self.allowed_hosts)
         if self.cors_config:
             asgi_handler = CORSMiddleware(app=asgi_handler, **self.cors_config.dict())
+        if self.csrf_config:
+            asgi_handler = CSRFMiddleware(app=asgi_handler, config=self.csrf_config)
         return self.wrap_in_exception_handler(asgi_handler, exception_handlers=self.exception_handlers or {})
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
