@@ -9,7 +9,7 @@ from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers import get
 
 if TYPE_CHECKING:
-    from openapi_schema_pydantic.v3.v3_1_0.open_api import OpenAPI
+    from pydantic_openapi_schema.v3_1_0.open_api import OpenAPI
 
 
 class OpenAPIController(Controller):
@@ -18,6 +18,7 @@ class OpenAPIController(Controller):
     style = "body { margin: 0; padding: 0 }"
     redoc_version = "next"
     swagger_ui_version = "4.13.0"
+    stoplight_elements_version = "7.6.3"
     favicon_url = ""
 
     # internal
@@ -104,6 +105,38 @@ class OpenAPIController(Controller):
             </html>
         """
 
+    @get(path="/elements/", media_type=MediaType.HTML, include_in_schema=False)
+    def stoplight_elements(self, request: Request) -> str:
+        """Endpoint that serves Stoplight Elements OpenAPI UI"""
+        schema = self.schema_from_request(request)
+        head = f"""
+          <head>
+            <title>{schema.info.title}</title>
+            {self.favicon}
+            <meta charset="utf-8"/>
+            <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
+            <link rel="stylesheet" href="https://unpkg.com/@stoplight/elements@{self.stoplight_elements_version}/styles.min.css">
+            <script src="https://unpkg.com/@stoplight/elements@{self.stoplight_elements_version}/web-components.min.js" crossorigin></script>
+            <style>{self.style}</style>
+          </head>
+        """
+        body = f"""
+          <body>
+            <elements-api
+                apiDescriptionUrl="{self.path}/openapi.json"
+                router="hash"
+                layout="sidebar"
+            />
+          </body>
+        """
+        return f"""
+        <!DOCTYPE html>
+            <html>
+                {head}
+                {body}
+            </html>
+        """
+
     @get(path=["/", "/redoc"], media_type=MediaType.HTML, include_in_schema=False)
     def redoc(self, request: Request) -> str:  # pragma: no cover
         """Endpoint that serves Redoc"""
