@@ -1,9 +1,7 @@
 from .base import PluginMapping, PluginProtocol, get_plugin_for_value
-from .sql_alchemy import SQLAlchemyPlugin
 
 __all__ = [
     "PluginMapping",
     "PluginProtocol",
-    "SQLAlchemyPlugin",
     "get_plugin_for_value",
 ]
